@@ -49,7 +49,7 @@ def run():
 
     # config section catches assertion errors and prints them as error messages
     CONFIG = None
-    try:
+    if os.path.isfile(os.path.join(os.getcwd(), 'config.py')):
         config_module = imp.load_source('config', os.path.join(os.getcwd(), 'config.py'))
         try:
             CONFIG = config_module.CONFIG
@@ -58,8 +58,6 @@ def run():
         except AttributeError:
             sys.stderr.write("Could not load CONFIG from config.py\n")
             sys.exit(1)
-    except IOError:
-        pass
 
     if CONFIG is None:
         from strange_case.strange_case_config import CONFIG
